"use strict";

var _interopRequireDefault = require("@babel/runtime-corejs3/helpers/interopRequireDefault");

exports.__esModule = true;
exports.Popup = void 0;

var _map = _interopRequireDefault(require("@babel/runtime-corejs3/core-js-stable/instance/map"));

var _core = require("@react-leaflet/core");

var _leaflet = require("leaflet");

var _react = require("react");

var Popup = (0, _core.createOverlayComponent)(function createPopup(props, context) {
  return {
    instance: new _leaflet.Popup(props, context.overlayContainer),
    context: context
  };
}, function usePopupLifecycle(element, context, props, setOpen) {
  (0, _react.useEffect)(function addPopup() {
    var instance = element.instance;

    function onPopupOpen(event) {
      if (event.popup === instance) {
        instance.update();
        setOpen(true);
        props.onOpen == null ? void 0 : props.onOpen();
      }
    }

    function onPopupClose(event) {
      if (event.popup === instance) {
        setOpen(false);
        props.onClose == null ? void 0 : props.onClose();
      }
    }

    (0, _map.default)(context).on({
      // @ts-ignore emits PopupEvent instead of LeafletEvent
      popupopen: onPopupOpen,
      // @ts-ignore emits PopupEvent instead of LeafletEvent
      popupclose: onPopupClose
    });

    if (context.overlayContainer == null) {
      // Attach to a Map
      if (props.position != null) {
        instance.setLatLng(props.position);
      }

      instance.openOn((0, _map.default)(context));
    } else {
      // Attach to container component
      context.overlayContainer.bindPopup(instance);
    }

    return function removePopup() {
      (0, _map.default)(context).off({
        // @ts-ignore emits PopupEvent instead of LeafletEvent
        popupopen: onPopupOpen,
        // @ts-ignore emits PopupEvent instead of LeafletEvent
        popupclose: onPopupClose
      });

      if (context.overlayContainer == null) {
        (0, _map.default)(context).removeLayer(instance);
      } else {
        context.overlayContainer.unbindPopup();
      }
    };
  }, [element, context, props, setOpen]);
});
exports.Popup = Popup;