import { createOverlayComponent } from '@react-leaflet/core';
import { Tooltip as LeafletTooltip } from 'leaflet';
import { useEffect } from 'react';
export var Tooltip = createOverlayComponent(function createTooltip(props, context) {
  return {
    instance: new LeafletTooltip(props, context.overlayContainer),
    context: context
  };
}, function useTooltipLifecycle(element, context, props, setOpen) {
  useEffect(function addTooltip() {
    var container = context.overlayContainer;

    if (container == null) {
      return;
    }

    var instance = element.instance;

    var onTooltipOpen = function onTooltipOpen(event) {
      if (event.tooltip === instance) {
        instance.update();
        setOpen(true);
        props.onOpen == null ? void 0 : props.onOpen();
      }
    };

    var onTooltipClose = function onTooltipClose(event) {
      if (event.tooltip === instance) {
        setOpen(false);
        props.onClose == null ? void 0 : props.onClose();
      }
    };

    container.on({
      // @ts-ignore emits TooltipEvent instead of LeafletEvent
      tooltipopen: onTooltipOpen,
      // @ts-ignore emits TooltipEvent instead of LeafletEvent
      tooltipclose: onTooltipClose
    });
    container.bindTooltip(instance);
    return function removeTooltip() {
      container.off({
        // @ts-ignore emits TooltipEvent instead of LeafletEvent
        tooltipopen: onTooltipOpen,
        // @ts-ignore emits TooltipEvent instead of LeafletEvent
        tooltipclose: onTooltipClose
      });
      container.unbindTooltip();
    };
  }, [element, context, setOpen, props.onClose, props.onOpen]);
});